import { AxiosInstance } from 'axios';
import Header from '../_APITool/Header';
import {
  UserAPIProps,
  GetUserSingleSignInAPIPromise,
  GetUserAccountInfoAPIPromise,
  PostUserSignOutAPIPromise,
} from './types';

export function CreatUserAPI({ axios, header }: { axios: AxiosInstance; header: Header }): UserAPIProps {
  return {
    getUserSSO: async (backUrl: string): Promise<GetUserSingleSignInAPIPromise> => {
      try {
        const res = await axios.get('/login', {
          params: {
            back_url: backUrl,
          },
        });
        return res.data;
      } catch (error) {
        const errorMessage = {
          url: '',
          error: error.response?.data,
        } as GetUserSingleSignInAPIPromise;
        return errorMessage;
      }
    },
    getUserAccountInfo: async (): Promise<GetUserAccountInfoAPIPromise> => {
      try {
        const res = await axios.get('/userinfo', {
          headers: { ...header.header },
        });
        return res.data;
      } catch (error) {
        const errorMessage = {
          display_name: '',
          email: '',
          groups: [],
          username: '',
        };
        return errorMessage;
      }
    },
    postUserSignOut: async (): Promise<PostUserSignOutAPIPromise> => {
      try {
        const res = await axios.post('/logout', undefined, {
          headers: { ...header.header },
        });
        return res.data;
      } catch (error) {
        const errorMessage = {
          url: '',
          error: error.response?.data,
        };
        return errorMessage;
      }
    },
  };
}
